<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Webservice Structure extenson
 *
 * @package		webservice
 * @category	Modules
 * @author		Rein de Vries <info@reinos.nl>
 * @link		http://reinos.nl/add-ons/webservice
 * @license  	http://reinos.nl/add-ons/commercial-license
 * @copyright 	Copyright (c) 2016 Reinos.nl Internet Media
 */

// ------------------------------------------------------------------------

class Webservice_structure_ext {

    var $name           = 'Webservice Structure';
    var $version        = '1.2.0';
    var $description    = 'Webservice Extension : Get some structure data';
    var $settings_exist = 'n';
    var $docs_url       = 'http://reinos.nl/add-ons/webservice/docs/extension-structure';
    var $settings       = array();

    /**
     * Constructor
     *
     * @param   mixed   Settings array or empty string if none exist.
     */
    function __construct($settings = '')
    {
        $this->EE =& get_instance();

        $this->settings = $settings;
    }

    /**
    * Activate Extension
    *
    * This function enters the extension into the exp_extensions table
    *
    * @see http://codeigniter.com/user_guide/database/index.html for
    * more information on the db class.
    *
    * @return void
    */
    function activate_extension()
    {
        $data = array(
            'class'     => __CLASS__,
            'method'    => 'get_structure_data',
            'hook'      => 'webservice_read_entry_end',
            'settings'  => serialize($this->settings),
            'priority'  => 10,
            'version'   => $this->version,
            'enabled'   => 'y'
        );

        $this->EE->db->insert('extensions', $data);

        $data = array(
            'class'     => __CLASS__,
            'method'    => 'get_structure_data',
            'hook'      => 'webservice_search_entry_per_entry',
            'settings'  => serialize($this->settings),
            'priority'  => 10,
            'version'   => $this->version,
            'enabled'   => 'y'
        );

        $this->EE->db->insert('extensions', $data);
    }

    /**
    * Update Extension
    *
    * This function performs any necessary db updates when the extension
    * page is visited
    *
    * @return  mixed   void on update / false if none
    */
    function update_extension($current = '')
    {
        if ($current == '' OR $current == $this->version)
        {
            return FALSE;
        }

        $this->EE->db->where('class', __CLASS__);
        $this->EE->db->update(
            'extensions',
            array('version' => $this->version)
        );
    }

    /**
    * Disable Extension
    *
    * This method removes information from the exp_extensions table
    *
    * @return void
    */
    function disable_extension()
    {
        $this->EE->db->where('class', __CLASS__);
        $this->EE->db->delete('extensions');
    }

    /**
    * Get the Playa parents
    *
    * @param array $entry_data
    * @return return array
    */
    function get_structure_data($entry_data = array())
    {
        /**
         * Include Structure SQL Model
         */
        require_once PATH_THIRD.'structure/sql.structure.php';

        /**
         * Include Structure Core Mod
         */
        require_once PATH_THIRD.'structure/mod.structure.php';

        //new instance of the SQL class
        $this->structure = new Structure();

        //get the tagdata
        $hidden_state = $this->structure->sql->get_hidden_state($entry_data['entry_id']);
        $listing_channel_id = $this->structure->sql->get_listing_channel_by_id($entry_data['entry_id']);
        $listing_channel_id = $listing_channel_id === false ? 0 : $listing_channel_id;
        $listing_channel_name = $this->get_channel_name($listing_channel_id);
        $total_listings = $this->count_listing_entry($listing_channel_id);

        //$get_listing_parent = $this->structure->sql->get_listing_parent($row['entry_id']);
        //set the data
        $structure_data = array(
            'structure' => array(
                'hide_from_nav' => $hidden_state,
                'hidden' => $hidden_state,
                'listing_channel_id' => $listing_channel_id,
                'listing_channel_name' => $listing_channel_name,
                'listings_total' => $total_listings,
            )
        );

        //try to get some parent data
        $this->site_pages = $this->structure->sql->get_site_pages();



        // Make sure there is Structure data
        if (array_key_exists('uris', $this->site_pages) && is_array($this->site_pages['uris']) && count($this->site_pages['uris']) > 0)
        {
            $settings = $this->structure->sql->get_settings();
            $trailing_slash = isset($settings['add_trailing_slash']) && $settings['add_trailing_slash'] === 'y' ? '/' : null;

            $this->entry_id = $entry_data['entry_id'];
            $this->parent_id = $this->structure->sql->get_parent_id($this->entry_id);
        }
        // current page global vars
        $structure_data['structure']['entry_id']           = $this->entry_id !== FALSE ? $this->entry_id : FALSE; // {page:entry_id}
        $structure_data['structure']['template_id']        = $this->entry_id !== FALSE ? $this->site_pages['templates'][$this->entry_id] : FALSE; // {page:template_id}
        $structure_data['structure']['title']              = $this->entry_id !== FALSE ? $this->structure->sql->get_page_title($this->entry_id) : FALSE; // {page:title}
        $structure_data['structure']['uri']                = $this->entry_id !== FALSE ? $this->site_pages['uris'][$this->entry_id] : FALSE;
        $structure_data['structure']['url']                = $this->entry_id !== FALSE ? Structure_Helper::remove_double_slashes($this->site_pages['url'] . $structure_data['structure']['uri']) : FALSE; // {page:url}
        $structure_data['structure']['channel']            = $this->entry_id !== FALSE ? $this->structure->sql->get_channel_by_entry_id($this->entry_id) : FALSE; // {page:channel}
        $structure_data['structure']['channel_short_name'] = $this->entry_id !== FALSE ?  $this->structure->sql->get_channel_name_by_channel_id($structure_data['structure']['channel']) : FALSE; // {page:channel_short_name}

        //parent
        $structure_data['structure']['parent']['entry_id']           = $this->parent_id !== FALSE ? $this->parent_id : FALSE; // {page:entry_id}
        $structure_data['structure']['parent']['title']              = $this->parent_id !== FALSE ? $this->structure->sql->get_page_title($this->parent_id) : FALSE; // {page:title}
        $structure_data['structure']['parent']['url_title']          = $this->parent_id !== FALSE && isset($this->site_pages['uris'][$this->parent_id]) ? array_pop(array_filter(explode('/',$this->site_pages['uris'][$this->parent_id])))  : FALSE; // {parent:relative_url}
        $structure_data['structure']['parent']['uri']                = $this->parent_id !== FALSE && isset($this->site_pages['uris'][$this->parent_id]) ? $this->site_pages['uris'][$this->parent_id]  : FALSE; // {parent:relative_url}
        $structure_data['structure']['parent']['url']                = $this->parent_id !== FALSE && $structure_data['structure']['parent']['uri'] !== FALSE ? Structure_Helper::remove_double_slashes($this->site_pages['url'] . $structure_data['structure']['parent']['uri'])  : FALSE; // {parent:url}
        $structure_data['structure']['parent']['channel']            = $this->parent_id !== FALSE ? $this->structure->sql->get_channel_by_entry_id($this->parent_id) : FALSE; // {page:channel}
        $structure_data['structure']['parent']['channel_short_name'] = $this->parent_id !== FALSE ?  $this->structure->sql->get_channel_name_by_channel_id($structure_data['structure']['parent']['channel']) : FALSE; // {page:channel_short_name}

        return array_merge($entry_data, $structure_data);
    }

    function get_channel_name($channel_id = '')
    {
        $this->EE->db->select('channel_name');
        $this->EE->db->where('channel_id', $channel_id);
        $query = $this->EE->db->get('channels');

        if($query->num_rows() > 0)
        {
            return $query->row()->channel_name;
        }
        return '';
    }

    function count_listing_entry($entry_id)
    {
        $sql = "SELECT * FROM exp_structure_listings WHERE channel_id = '$entry_id' AND site_id = ".$this->EE->config->item('site_id');
        $result = $this->EE->db->query($sql);
        return $result->num_rows();
    }

}

/* End of file ext.webservice_structure.php */
/* Location: /system/expressionengine/third_party/webservice_structure/ext.webservice_structure.php */